/**
 * Calculates the maturity amount of a Systematic Investment Plan (SIP).
 * @param monthlyInvestment - The amount invested monthly.
 * @param annualReturnRate - The annual return rate (in percentage).
 * @param totalYears - The total number of investment months.
 * @returns The maturity amount.
 * @throws Error if any parameter is invalid.
 */
export declare function calculateSIP(monthlyInvestment: number, annualReturnRate: number, totalYears: number): number;
/**
 * Calculates the maturity amount of a Systematic Investment Plan (SIP) with an annual step-up.
 * @param initialInvestment - The initial monthly investment amount.
 * @param annualReturnRate - The annual return rate (in percentage).
 * @param totalYears - The total number of investment years.
 * @param stepUpRate - The annual step-up rate (in percentage).
 * @returns The maturity amount.
 * @throws Error if any parameter is invalid.
 */
export declare function calculateStepUpSIP(initialInvestment: number, annualReturnRate: number, totalYears: number, stepUpRate: number): number;
/**
 * Calculates the duration (in months) for which an investment will last with a Systematic Withdrawal Plan (SWP).
 * @param initialCorpus - The initial investment corpus.
 * @param withdrawalAmount - The fixed amount withdrawn at regular intervals (monthly).
 * @param annualReturnRate - The annual return rate (in percentage).
 * @returns The number of months the corpus will last.
 * @throws Error if any parameter is invalid.
 */
export declare function calculateSWPDuration(initialCorpus: number, withdrawalAmount: number, annualReturnRate: number): number;
/**
 * Calculates the fixed monthly withdrawal amount for a desired duration with a Systematic Withdrawal Plan (SWP).
 * @param initialCorpus - The initial investment corpus.
 * @param durationMonths - The desired duration in months.
 * @param annualReturnRate - The annual return rate (in percentage).
 * @returns The fixed monthly withdrawal amount.
 * @throws Error if any parameter is invalid.
 */
export declare function calculateSWPAmount(initialCorpus: number, durationMonths: number, annualReturnRate: number): number;
/**
 * Calculates the future value of a lumpsum investment.
 * @param principal - The initial investment amount (lumpsum).
 * @param annualReturnRate - The annual return rate (in percentage).
 * @param totalYears - The total number of years for which the investment is made.
 * @returns The future value of the lumpsum investment.
 * @throws Error if any parameter is invalid.
 */
export declare function calculateLumpsum(principal: number, annualReturnRate: number, totalYears: number): number;
